package ca.uhn.hl7v2.model.v25.group;

import ca.uhn.hl7v2.parser.ModelClassFactory;
import ca.uhn.hl7v2.HL7Exception;
import ca.uhn.log.HapiLogFactory;
import ca.uhn.hl7v2.model.v25.segment.*;

import ca.uhn.hl7v2.model.*;
/**
 * <p>Represents the CSU_C09_STUDY_SCHEDULE Group.  A Group is an ordered collection of message 
 * segments that can repeat together or be optionally in/excluded together.
 * This Group contains the following elements: </p>
 * 0: CSS (Clinical Study Data Schedule Segment) <b>optional </b><br>
 * 1: CSU_C09_STUDY_OBSERVATION (a Group object) <b>repeating</b><br>
 * 2: CSU_C09_STUDY_PHARM (a Group object) <b>repeating</b><br>
 */
public class CSU_C09_STUDY_SCHEDULE extends AbstractGroup {

	/** 
	 * Creates a new CSU_C09_STUDY_SCHEDULE Group.
	 */
	public CSU_C09_STUDY_SCHEDULE(Group parent, ModelClassFactory factory) {
	   super(parent, factory);
	   try {
	      this.add(CSS.class, false, false);
	      this.add(CSU_C09_STUDY_OBSERVATION.class, true, true);
	      this.add(CSU_C09_STUDY_PHARM.class, true, true);
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error creating CSU_C09_STUDY_SCHEDULE - this is probably a bug in the source code generator.", e);
	   }
	}

	/**
	 * Returns CSS (Clinical Study Data Schedule Segment) - creates it if necessary
	 */
	public CSS getCSS() { 
	   CSS ret = null;
	   try {
	      ret = (CSS)this.get("CSS");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns  first repetition of CSU_C09_STUDY_OBSERVATION (a Group object) - creates it if necessary
	 */
	public CSU_C09_STUDY_OBSERVATION getSTUDY_OBSERVATION() { 
	   CSU_C09_STUDY_OBSERVATION ret = null;
	   try {
	      ret = (CSU_C09_STUDY_OBSERVATION)this.get("STUDY_OBSERVATION");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of CSU_C09_STUDY_OBSERVATION
	 * (a Group object) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public CSU_C09_STUDY_OBSERVATION getSTUDY_OBSERVATION(int rep) throws HL7Exception { 
	   return (CSU_C09_STUDY_OBSERVATION)this.get("STUDY_OBSERVATION", rep);
	}

	/** 
	 * Returns the number of existing repetitions of CSU_C09_STUDY_OBSERVATION 
	 */ 
	public int getSTUDY_OBSERVATIONReps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("STUDY_OBSERVATION").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of CSU_C09_STUDY_OBSERVATION
	 * (a Group object)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertSTUDY_OBSERVATION(CSU_C09_STUDY_OBSERVATION structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of CSU_C09_STUDY_OBSERVATION
	 * (a Group object)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public CSU_C09_STUDY_OBSERVATION insertSTUDY_OBSERVATION(int rep) throws HL7Exception { 
	   return (CSU_C09_STUDY_OBSERVATION)super.insertRepetition("STUDY_OBSERVATION", rep);
	}

	/**
	 * Removes a specific repetition of CSU_C09_STUDY_OBSERVATION
	 * (a Group object)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public CSU_C09_STUDY_OBSERVATION removeSTUDY_OBSERVATION(int rep) throws HL7Exception { 
	   return (CSU_C09_STUDY_OBSERVATION)super.removeRepetition("STUDY_OBSERVATION", rep);
	}

	/**
	 * Returns  first repetition of CSU_C09_STUDY_PHARM (a Group object) - creates it if necessary
	 */
	public CSU_C09_STUDY_PHARM getSTUDY_PHARM() { 
	   CSU_C09_STUDY_PHARM ret = null;
	   try {
	      ret = (CSU_C09_STUDY_PHARM)this.get("STUDY_PHARM");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of CSU_C09_STUDY_PHARM
	 * (a Group object) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public CSU_C09_STUDY_PHARM getSTUDY_PHARM(int rep) throws HL7Exception { 
	   return (CSU_C09_STUDY_PHARM)this.get("STUDY_PHARM", rep);
	}

	/** 
	 * Returns the number of existing repetitions of CSU_C09_STUDY_PHARM 
	 */ 
	public int getSTUDY_PHARMReps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("STUDY_PHARM").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of CSU_C09_STUDY_PHARM
	 * (a Group object)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertSTUDY_PHARM(CSU_C09_STUDY_PHARM structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of CSU_C09_STUDY_PHARM
	 * (a Group object)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public CSU_C09_STUDY_PHARM insertSTUDY_PHARM(int rep) throws HL7Exception { 
	   return (CSU_C09_STUDY_PHARM)super.insertRepetition("STUDY_PHARM", rep);
	}

	/**
	 * Removes a specific repetition of CSU_C09_STUDY_PHARM
	 * (a Group object)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public CSU_C09_STUDY_PHARM removeSTUDY_PHARM(int rep) throws HL7Exception { 
	   return (CSU_C09_STUDY_PHARM)super.removeRepetition("STUDY_PHARM", rep);
	}

}
