package ca.uhn.hl7v2.model.v25.group;

import ca.uhn.hl7v2.parser.ModelClassFactory;
import ca.uhn.hl7v2.HL7Exception;
import ca.uhn.log.HapiLogFactory;
import ca.uhn.hl7v2.model.v25.segment.*;

import ca.uhn.hl7v2.model.*;
/**
 * <p>Represents the MFR_M05_MF_QUERY Group.  A Group is an ordered collection of message 
 * segments that can repeat together or be optionally in/excluded together.
 * This Group contains the following elements: </p>
 * 0: MFE (Master File Entry) <b></b><br>
 * 1: LOC (Location Identification) <b></b><br>
 * 2: LCH (Location Characteristic) <b>optional repeating</b><br>
 * 3: LRL (Location Relationship) <b>optional repeating</b><br>
 * 4: LDP (Location Department) <b>repeating</b><br>
 * 5: LCH (Location Characteristic) <b>optional repeating</b><br>
 * 6: LCC (Location Charge Code) <b>optional repeating</b><br>
 */
public class MFR_M05_MF_QUERY extends AbstractGroup {

	/** 
	 * Creates a new MFR_M05_MF_QUERY Group.
	 */
	public MFR_M05_MF_QUERY(Group parent, ModelClassFactory factory) {
	   super(parent, factory);
	   try {
	      this.add(MFE.class, true, false);
	      this.add(LOC.class, true, false);
	      this.add(LCH.class, false, true);
	      this.add(LRL.class, false, true);
	      this.add(LDP.class, true, true);
	      this.add(LCH.class, false, true);
	      this.add(LCC.class, false, true);
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error creating MFR_M05_MF_QUERY - this is probably a bug in the source code generator.", e);
	   }
	}

	/**
	 * Returns MFE (Master File Entry) - creates it if necessary
	 */
	public MFE getMFE() { 
	   MFE ret = null;
	   try {
	      ret = (MFE)this.get("MFE");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns LOC (Location Identification) - creates it if necessary
	 */
	public LOC getLOC() { 
	   LOC ret = null;
	   try {
	      ret = (LOC)this.get("LOC");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns  first repetition of LCH (Location Characteristic) - creates it if necessary
	 */
	public LCH getLCH() { 
	   LCH ret = null;
	   try {
	      ret = (LCH)this.get("LCH");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of LCH
	 * (Location Characteristic) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public LCH getLCH(int rep) throws HL7Exception { 
	   return (LCH)this.get("LCH", rep);
	}

	/** 
	 * Returns the number of existing repetitions of LCH 
	 */ 
	public int getLCHReps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("LCH").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of LCH
	 * (Location Characteristic)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertLCH(LCH structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of LCH
	 * (Location Characteristic)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public LCH insertLCH(int rep) throws HL7Exception { 
	   return (LCH)super.insertRepetition("LCH", rep);
	}

	/**
	 * Removes a specific repetition of LCH
	 * (Location Characteristic)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public LCH removeLCH(int rep) throws HL7Exception { 
	   return (LCH)super.removeRepetition("LCH", rep);
	}

	/**
	 * Returns  first repetition of LRL (Location Relationship) - creates it if necessary
	 */
	public LRL getLRL() { 
	   LRL ret = null;
	   try {
	      ret = (LRL)this.get("LRL");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of LRL
	 * (Location Relationship) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public LRL getLRL(int rep) throws HL7Exception { 
	   return (LRL)this.get("LRL", rep);
	}

	/** 
	 * Returns the number of existing repetitions of LRL 
	 */ 
	public int getLRLReps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("LRL").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of LRL
	 * (Location Relationship)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertLRL(LRL structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of LRL
	 * (Location Relationship)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public LRL insertLRL(int rep) throws HL7Exception { 
	   return (LRL)super.insertRepetition("LRL", rep);
	}

	/**
	 * Removes a specific repetition of LRL
	 * (Location Relationship)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public LRL removeLRL(int rep) throws HL7Exception { 
	   return (LRL)super.removeRepetition("LRL", rep);
	}

	/**
	 * Returns  first repetition of LDP (Location Department) - creates it if necessary
	 */
	public LDP getLDP() { 
	   LDP ret = null;
	   try {
	      ret = (LDP)this.get("LDP");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of LDP
	 * (Location Department) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public LDP getLDP(int rep) throws HL7Exception { 
	   return (LDP)this.get("LDP", rep);
	}

	/** 
	 * Returns the number of existing repetitions of LDP 
	 */ 
	public int getLDPReps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("LDP").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of LDP
	 * (Location Department)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertLDP(LDP structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of LDP
	 * (Location Department)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public LDP insertLDP(int rep) throws HL7Exception { 
	   return (LDP)super.insertRepetition("LDP", rep);
	}

	/**
	 * Removes a specific repetition of LDP
	 * (Location Department)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public LDP removeLDP(int rep) throws HL7Exception { 
	   return (LDP)super.removeRepetition("LDP", rep);
	}

	/**
	 * Returns  first repetition of LCH2 (Location Characteristic) - creates it if necessary
	 */
	public LCH getLCH2() { 
	   LCH ret = null;
	   try {
	      ret = (LCH)this.get("LCH2");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of LCH2
	 * (Location Characteristic) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public LCH getLCH2(int rep) throws HL7Exception { 
	   return (LCH)this.get("LCH2", rep);
	}

	/** 
	 * Returns the number of existing repetitions of LCH2 
	 */ 
	public int getLCH2Reps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("LCH2").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of LCH2
	 * (Location Characteristic)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertLCH2(LCH structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of LCH2
	 * (Location Characteristic)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public LCH insertLCH2(int rep) throws HL7Exception { 
	   return (LCH)super.insertRepetition("LCH2", rep);
	}

	/**
	 * Removes a specific repetition of LCH2
	 * (Location Characteristic)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public LCH removeLCH2(int rep) throws HL7Exception { 
	   return (LCH)super.removeRepetition("LCH2", rep);
	}

	/**
	 * Returns  first repetition of LCC (Location Charge Code) - creates it if necessary
	 */
	public LCC getLCC() { 
	   LCC ret = null;
	   try {
	      ret = (LCC)this.get("LCC");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of LCC
	 * (Location Charge Code) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public LCC getLCC(int rep) throws HL7Exception { 
	   return (LCC)this.get("LCC", rep);
	}

	/** 
	 * Returns the number of existing repetitions of LCC 
	 */ 
	public int getLCCReps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("LCC").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of LCC
	 * (Location Charge Code)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertLCC(LCC structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of LCC
	 * (Location Charge Code)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public LCC insertLCC(int rep) throws HL7Exception { 
	   return (LCC)super.insertRepetition("LCC", rep);
	}

	/**
	 * Removes a specific repetition of LCC
	 * (Location Charge Code)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public LCC removeLCC(int rep) throws HL7Exception { 
	   return (LCC)super.removeRepetition("LCC", rep);
	}

}
