package ca.uhn.hl7v2.model.v25.group;

import ca.uhn.hl7v2.parser.ModelClassFactory;
import ca.uhn.hl7v2.HL7Exception;
import ca.uhn.log.HapiLogFactory;
import ca.uhn.hl7v2.model.v25.segment.*;

import ca.uhn.hl7v2.model.*;
/**
 * <p>Represents the RSP_Z88_ORDER_ENCODED Group.  A Group is an ordered collection of message 
 * segments that can repeat together or be optionally in/excluded together.
 * This Group contains the following elements: </p>
 * 0: RXE (Pharmacy/Treatment Encoded Order) <b></b><br>
 * 1: RSP_Z88_TIMING_ENCODED (a Group object) <b>optional repeating</b><br>
 * 2: RXR (Pharmacy/Treatment Route) <b>repeating</b><br>
 * 3: RXC (Pharmacy/Treatment Component Order) <b>optional repeating</b><br>
 */
public class RSP_Z88_ORDER_ENCODED extends AbstractGroup {

	/** 
	 * Creates a new RSP_Z88_ORDER_ENCODED Group.
	 */
	public RSP_Z88_ORDER_ENCODED(Group parent, ModelClassFactory factory) {
	   super(parent, factory);
	   try {
	      this.add(RXE.class, true, false);
	      this.add(RSP_Z88_TIMING_ENCODED.class, false, true);
	      this.add(RXR.class, true, true);
	      this.add(RXC.class, false, true);
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error creating RSP_Z88_ORDER_ENCODED - this is probably a bug in the source code generator.", e);
	   }
	}

	/**
	 * Returns RXE (Pharmacy/Treatment Encoded Order) - creates it if necessary
	 */
	public RXE getRXE() { 
	   RXE ret = null;
	   try {
	      ret = (RXE)this.get("RXE");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns  first repetition of RSP_Z88_TIMING_ENCODED (a Group object) - creates it if necessary
	 */
	public RSP_Z88_TIMING_ENCODED getTIMING_ENCODED() { 
	   RSP_Z88_TIMING_ENCODED ret = null;
	   try {
	      ret = (RSP_Z88_TIMING_ENCODED)this.get("TIMING_ENCODED");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of RSP_Z88_TIMING_ENCODED
	 * (a Group object) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public RSP_Z88_TIMING_ENCODED getTIMING_ENCODED(int rep) throws HL7Exception { 
	   return (RSP_Z88_TIMING_ENCODED)this.get("TIMING_ENCODED", rep);
	}

	/** 
	 * Returns the number of existing repetitions of RSP_Z88_TIMING_ENCODED 
	 */ 
	public int getTIMING_ENCODEDReps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("TIMING_ENCODED").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of RSP_Z88_TIMING_ENCODED
	 * (a Group object)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertTIMING_ENCODED(RSP_Z88_TIMING_ENCODED structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of RSP_Z88_TIMING_ENCODED
	 * (a Group object)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public RSP_Z88_TIMING_ENCODED insertTIMING_ENCODED(int rep) throws HL7Exception { 
	   return (RSP_Z88_TIMING_ENCODED)super.insertRepetition("TIMING_ENCODED", rep);
	}

	/**
	 * Removes a specific repetition of RSP_Z88_TIMING_ENCODED
	 * (a Group object)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public RSP_Z88_TIMING_ENCODED removeTIMING_ENCODED(int rep) throws HL7Exception { 
	   return (RSP_Z88_TIMING_ENCODED)super.removeRepetition("TIMING_ENCODED", rep);
	}

	/**
	 * Returns  first repetition of RXR (Pharmacy/Treatment Route) - creates it if necessary
	 */
	public RXR getRXR() { 
	   RXR ret = null;
	   try {
	      ret = (RXR)this.get("RXR");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of RXR
	 * (Pharmacy/Treatment Route) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public RXR getRXR(int rep) throws HL7Exception { 
	   return (RXR)this.get("RXR", rep);
	}

	/** 
	 * Returns the number of existing repetitions of RXR 
	 */ 
	public int getRXRReps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("RXR").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of RXR
	 * (Pharmacy/Treatment Route)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertRXR(RXR structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of RXR
	 * (Pharmacy/Treatment Route)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public RXR insertRXR(int rep) throws HL7Exception { 
	   return (RXR)super.insertRepetition("RXR", rep);
	}

	/**
	 * Removes a specific repetition of RXR
	 * (Pharmacy/Treatment Route)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public RXR removeRXR(int rep) throws HL7Exception { 
	   return (RXR)super.removeRepetition("RXR", rep);
	}

	/**
	 * Returns  first repetition of RXC (Pharmacy/Treatment Component Order) - creates it if necessary
	 */
	public RXC getRXC() { 
	   RXC ret = null;
	   try {
	      ret = (RXC)this.get("RXC");
	   } catch(HL7Exception e) {
	      HapiLogFactory.getHapiLog(this.getClass()).error("Unexpected error accessing data - this is probably a bug in the source code generator.", e);
	      throw new RuntimeException(e);
	   }
	   return ret;
	}

	/**
	 * Returns a specific repetition of RXC
	 * (Pharmacy/Treatment Component Order) - creates it if necessary
	 * @throws HL7Exception if the repetition requested is more than one 
	 *     greater than the number of existing repetitions.
	 */
	public RXC getRXC(int rep) throws HL7Exception { 
	   return (RXC)this.get("RXC", rep);
	}

	/** 
	 * Returns the number of existing repetitions of RXC 
	 */ 
	public int getRXCReps() { 
	    int reps = -1; 
	    try { 
	        reps = this.getAll("RXC").length; 
	    } catch (HL7Exception e) { 
	        String message = "Unexpected error accessing data - this is probably a bug in the source code generator."; 
	        HapiLogFactory.getHapiLog(this.getClass()).error(message, e); 
	        throw new RuntimeException(message);
	    } 
	    return reps; 
	} 

	/**
	 * Inserts a specific repetition of RXC
	 * (Pharmacy/Treatment Component Order)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public void  insertRXC(RXC structure, int rep) throws HL7Exception { 
	   super.insertRepetition( structure, rep);
	}

	/**
	 * Inserts a specific repetition of RXC
	 * (Pharmacy/Treatment Component Order)
	 * @see AbstractGroup#insertRepetition(Structure, int) 
	 */
	public RXC insertRXC(int rep) throws HL7Exception { 
	   return (RXC)super.insertRepetition("RXC", rep);
	}

	/**
	 * Removes a specific repetition of RXC
	 * (Pharmacy/Treatment Component Order)
	 * @see AbstractGroup#insertremoveRepetition(String, int) 
	 */
	public RXC removeRXC(int rep) throws HL7Exception { 
	   return (RXC)super.removeRepetition("RXC", rep);
	}

}
